pub struct GitFetcher { /* private fields */ }Expand description
Git repository fetcher for bootloader files.
Implementations
Sourceimpl GitFetcher
impl GitFetcher
Sourcepub fn new(cache_dir: PathBuf) -> Self
pub fn new(cache_dir: PathBuf) -> Self
Create a new git fetcher with the specified cache directory.
Sourcepub fn fetch(&self, url: &str, name: &str, branch: &str) -> Result<PathBuf>
pub fn fetch(&self, url: &str, name: &str, branch: &str) -> Result<PathBuf>
Fetch a git repository to the cache directory.
If the repository already exists, it will be used as-is. If not, it will be cloned from the URL.