pub struct ImageRunner { /* private fields */ }Expand description
Image runner that orchestrates the build and run process.
Implementations
Sourceimpl ImageRunner
impl ImageRunner
Sourcepub fn build_image(&self) -> Result<PathBuf>
pub fn build_image(&self) -> Result<PathBuf>
Build the image without running it.
Returns the path to the built image.
Sourcepub fn run(self) -> Result<()>
pub fn run(self) -> Result<()>
Run the full pipeline: prepare bootloader, build image, execute.
Returns Ok(()) on success or an error on failure.
If an I/O handler was set, it will be used during execution.
Sourcepub fn run_with_result(self) -> Result<RunResult>
pub fn run_with_result(self) -> Result<RunResult>