pub struct LimineBootloader { /* private fields */ }Expand description
Limine bootloader implementation.
Limine is a modern, feature-rich bootloader that supports both BIOS and UEFI. This implementation fetches Limine binaries from the official repository and configures them based on the user’s limine.conf file.
Implementations
Sourceimpl LimineBootloader
impl LimineBootloader
Sourcepub fn with_repo_url(repo_url: String) -> Self
pub fn with_repo_url(repo_url: String) -> Self
Create a Limine bootloader with a custom repository URL.